@@ -1,21 +1,7 @@
-/*
-  LV2 Sampler Example Plugin
-  Copyright 2011-2016 David Robillard <d@drobilla.net>
-  Copyright 2011 Gabriel M. Beddingfield <gabriel@teuton.org>
-  Copyright 2011 James Morris <jwm.art.net@gmail.com>
-
-  Permission to use, copy, modify, and/or distribute this software for any
-  purpose with or without fee is hereby granted, provided that the above
-  copyright notice and this permission notice appear in all copies.
-
-  THIS SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-*/
+// Copyright 2011-2016 David Robillard <d@drobilla.net>
+// Copyright 2011 Gabriel M. Beddingfield <gabriel@teuton.org>
+// Copyright 2011 James Morris <jwm.art.net@gmail.com>
+// SPDX-License-Identifier: ISC
 
 #include "atom_sink.h"
 #include "peaks.h"
@@ -148,7 +134,7 @@ load_sample(LV2_Log_Logger* logger, const char* path, const int sample_rate)
     return NULL;
   }
 
-  sf_seek(sndfile, 0ul, SEEK_SET);
+  sf_seek(sndfile, 0UL, SEEK_SET);
   sf_read_float(sndfile, data, info->frames * info->channels);
   sf_close(sndfile);
 
